# Approver - Approve Transaction

The approver is responsible for verifying a transaction proposed by a [proposer](../../../../system-roles.md).

## Requirements

* [Quorum PGP Key](../operator/quorum-entropy-ceremony.md)

* [Online Machine](TODO)

* [SD Card Pack](../provisioner/provision-sd-card.md)

* [Air-Gapped Bundle](../provisioner/air-gapped-bundle.md)

	* The approver should print photographic evidence from digital cameras which is stored in a PGP signed repository. The photographs should be of the top and underside of the vacuum sealed object.

	* The approver should verify the commit signatures of the photographs they are printing against a list of permitted PGP keys found in the `vaults` repo

* Ensure that the computer is configured to sign commits with the desired key. Refer to the [Appendix: Git Commit Signing Configuration](#git-commit-signing-configuration)

* Clone the [Vaults Repository](../../../all-levels/create-vaults-repository.md) for your organization to the machine

## Procedure

1. Turn on online machine 

1. Pull the latest changes from the `vaults` repository

1. Unseal the SD Card Pack

{{ #include ../../../../component-documents/tamper-evidence-methods.md:vsbwf-procedure-unsealing}}

1. Plug a fresh SD card into the online machine

1. Save the `vaults` repository to the SD card, referred to as the Ceremony SD card

1. Unplug the Ceremony SD card

1. Unseal the tamper proofed bundle

{{ #include ../../../../component-documents/tamper-evidence-methods.md:vsbwf-procedure-unsealing}}

1. Insert the AirgapOS SD card into the airgapped machine and turn it on

1. Once booted, unplug the AirgapOS SD card 

1. Plug in the Ceremony SD card

1. {{ #include ../../../../component-documents/finding-device-name.md:content }}

1. Plug in the Operator smart card

1. Set a local variable `pgp_key_id` to the smart card OpenPGP key id:
    
    * `pgp_key_id="$(oct list -i | head -1)"`

1. Copy the git repo locally from the Ceremony SD card

	* `cp -r /media/<device_name>/vaults /root/vaults`

1. Change directory to vaults 

	* `cd /root/vaults`

1. Verify the detached signature for the payload

	* `gpg --verify <payload>.<num>.json <payload>.<num>.<key_id>.sig`

	* The filename will be of format: `/<namespace>/ceremonies/<date>/payloads/payload_<number>.json`

1. Verify the key is authenticated:

	* `sq-wot --gpg list "<their@email.co>"`

	* Ensure the output of the command includes "fully authenticated"

1. Sign the transaction payload:

    * `gpg --detach-sign <namespace>/ceremonies/<date>/payloads/payload_<num>.json > <namespace>/ceremonies/<date>/payloads/payload_<num>_$pgp_key_id.sig`

	* e.g `gpg --detach-sign solana-01/ceremonies/2025-01-01/payloads/payload_1.json > solana-01/ceremonies/2025-01-01/payloads/payload_1_F4BF5C81EC78A5DD341C91EEDC4B7D1F52E0BA4D.sig`

1. Stage the modified file:

    * `git add <namespace>/ceremonies/<date>/payloads/payload_<num>_$pgp_key_id.sig`

1. Create a signed git commit:

	* `git commit -S -m "add payload signature for payload_<num>.json using $pgp_key_id"`

1. {{ #include ../../../../component-documents/finding-device-name.md:content }}

1. Copy the updated vaults repo to the SD card

	* `cp -r /root/vaults /media/<device_name>/vaults`

1. Unplug the SD card from the air-gapped machine

1. Plug in the SD card into the online machine

1. {{ #include ../../../../component-documents/finding-device-name.md:content }}

1. Copy the updated repository locally:

	* `cp -r /media/<device_name>/vaults ~/`

1. Change into locally copied directory

	* `cd ~/vaults`

1. Push the latest commit to the repository
	
	* `git push origin main`

1. Tamper proof the AirgapOS and Air-gapped laptop

{{ #include ../../../../component-documents/tamper-evidence-methods.md:vsbwf-procedure-sealing}}
